//
//  HomeViewController.m
//  PLS Mobile
//
//  Created by Daniel Workman on 25/04/2013.
//  Copyright (c) 2013 Daniel Workman. All rights reserved.
//

#import "HomeViewController.h"
#import "JobsViewController.h"
#import "JobDetailsViewController.h"
#import "ASIHTTPRequest.h"
#import "ASIFormDataRequest.h"
#import "SBJson.h"
#import "MBProgressHUD.h"
#import "GlobalObjects.h"

@interface HomeViewController ()

@end

@implementation HomeViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)enableBtn:(UIButton*)button enable:(BOOL)enable {
    button.enabled = enable;
    button.alpha = enable ? 1.0 : 0.5;
}

- (void)viewDidLoad
{
    [self enableBtn:self.jobsButton enable:NO];
    [self enableBtn:self.currentJobButton enable:NO];
    
    [super viewDidLoad];
}

- (void)viewWillAppear:(BOOL)animated
{
    [self loadJob];
}

- (void)loadJob {
    NSString *urlString = [[NSUserDefaults standardUserDefaults] stringForKey:@"database_url"];
    ASIFormDataRequest *request = [ASIFormDataRequest requestWithURL:[NSURL URLWithString:urlString]];
    [request setPostValue:@"jobs" forKey:@"request"];
    [request setPostValue:[GlobalObjects getCurrentUser] forKey:@"username"];
    [request setPostValue:[NSString stringWithFormat:@"%d", JOB_STATUS_ACCEPTED] forKey:@"status"];
    [request setDelegate:self];
    [request startAsynchronous];
    
    MBProgressHUD *hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
    hud.labelText = @"Retrieving jobs...";
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (IBAction)refreshButtonPressed:(id)sender {
    [self loadJob];
}

- (void)requestFinished:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];

    if (request.responseStatusCode == 200) {
        // the user has an active open job
        NSString *responseString = [request responseString];
        NSDictionary *responseDict = [responseString JSONValue];

        for (NSString *key in responseDict) {
            NSDictionary *job = [responseDict objectForKey:key];
            self.jobId = [[job objectForKey:@"id"] integerValue];
            
            [self enableBtn:self.jobsButton enable:NO];
            [self enableBtn:self.currentJobButton enable:YES];

            // There should only be one active job so return now
            return;
        }

        // currently no active job is open so allow user to view all waiting jobs
        [self enableBtn:self.jobsButton enable:YES];
        [self enableBtn:self.currentJobButton enable:NO];
    }
    else {
        ALERT(@"Request Failed", request.responseStatusMessage);
    }
}

- (void)requestFailed:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];
    ALERT(@"Request Failed", [[request error] localizedDescription]);
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    // The the view whether it is to load active or completed jobs
    if ([[segue identifier] isEqualToString:@"GetJobs"]) {
        JobsViewController *vc = [segue destinationViewController];
        vc.status = JOB_STATUS_WAITING;
    }
    else if ([[segue identifier] isEqualToString:@"GetCompletedJobs"]) {
        JobsViewController *vc = [segue destinationViewController];
        vc.status = JOB_STATUS_COMPLETED;
        vc.navigationItem.title = @"Completed Jobs";
    }
    else if ([[segue identifier] isEqualToString:@"GetActiveJob"]) {
        JobDetailsViewController *vc = [segue destinationViewController];
        vc.status = JOB_STATUS_ACCEPTED;
        vc.jobId = self.jobId;
    }
}

@end
