//
//  JobDetailViewController.m
//  PLS Mobile
//
//  Created by Daniel Workman on 27/04/2013.
//  Copyright (c) 2013 Daniel Workman. All rights reserved.
//

#import "JobDetailsViewController.h"
#import "ASIHTTPRequest.h"
#import "ASIFormDataRequest.h"
#import "SBJson.h"
#import "MBProgressHUD.h"
#import "SiteDetailsViewController.h"
#import "ATMDetailsViewController.h"
#import "PartsViewController.h"
#import "Part.h"
#import "ReportViewController.h"

@interface JobDetailsViewController ()

@end

@implementation JobDetailsViewController

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    if (JOB_STATUS_WAITING == self.status) {
        self.abortCell.hidden = TRUE;
        self.completeCell.textLabel.text = @"Accept Job";
    } else if (JOB_STATUS_COMPLETED == self.status) {
        self.completeCell.hidden = TRUE;
        self.abortCell.hidden = TRUE;
    }

    self.parts = [NSMutableArray arrayWithCapacity:5];

    // Start request
    NSString *urlString = [[NSUserDefaults standardUserDefaults] stringForKey:@"database_url"];
    ASIFormDataRequest *request = [ASIFormDataRequest requestWithURL:[NSURL URLWithString:urlString]];
    [request setPostValue:@"job" forKey:@"request"];
    [request setPostValue:[NSString stringWithFormat:@"%d", self.jobId] forKey:@"job_id"];
    [request setDelegate:self];
    [request startAsynchronous];

    MBProgressHUD *hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
    hud.labelText = @"Loading job...";
    hud.userInteractionEnabled = NO;
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    self.partsCell.detailTextLabel.text = [NSString stringWithFormat:@"%d used", [self countParts]];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (NSInteger)countParts
{
    NSInteger count = 0;
    for (Part *part in self.parts) count += part.quantity;
    return count;
}

- (void)requestFinished:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];
    
    if (request.responseStatusCode == 200) {        
        if ([@"Job Updated Successfully" isEqualToString:request.responseString]) {
            self.status = JOB_STATUS_ACCEPTED;
        } else {
            NSString *responseString = [request responseString];
            NSDictionary *responseDict = [responseString JSONValue];

            self.descriptionCell.textLabel.text = [responseDict objectForKey:@"description"];
            self.detailsText.text = [responseDict objectForKey:@"job_details"];
            self.parkingText.text = [responseDict objectForKey:@"parking"];
            self.siteCell.tag = [[responseDict objectForKey:@"site_id"] integerValue];
            self.siteCell.detailTextLabel.text = [responseDict objectForKey:@"site_name"];
            self.ATMCell.tag = [[responseDict objectForKey:@"atm_id"] integerValue];
            self.ATMCell.detailTextLabel.text = [responseDict objectForKey:@"atm_name"];
            
            NSDictionary *parts = [responseDict objectForKey:@"parts"];
            
            for (NSDictionary *partDict in parts) {
                //NSDictionary *part = [parts objectForKey:key];
                Part *part = [[Part alloc] init];
                part.partId = [[partDict objectForKey:@"part_id"] integerValue];
                part.make = [partDict objectForKey:@"make"];
                part.model = [partDict objectForKey:@"model"];
                part.quantity = [[partDict objectForKey:@"quantity"] integerValue];
                
                [self.parts addObject:part];
            }
            
            self.partsCell.detailTextLabel.text = [NSString stringWithFormat:@"%d used", [self countParts]];
        }
        
        [self.tableView reloadData];
    } else {
        ALERT(@"Request Failed", request.responseStatusMessage);
    }
}

- (void)requestFailed:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];
    ALERT(@"Request Failed", [[request error] localizedDescription]);
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    if ([[segue identifier] isEqualToString:@"SiteDetails"]) {
        SiteDetailsViewController *vc = [segue destinationViewController];
        [vc setSiteId:self.siteCell.tag];
    }
    else if ([[segue identifier] isEqualToString:@"ATMDetails"]) {
        ATMDetailsViewController *vc = [segue destinationViewController];
        [vc setATMId:self.ATMCell.tag];
    }
    else if ([[segue identifier] isEqualToString:@"Parts"]) {
        PartsViewController *vc = [segue destinationViewController];
        [vc setSender:self];
        [vc setStatus:self.status];
    }
    else if ([[segue identifier] isEqualToString:@"CompleteJob"]) {
        ReportViewController *vc = [segue destinationViewController];
        [vc setSender:self];
        [vc setStatus:JOB_STATUS_COMPLETED];
    }
    else if ([[segue identifier] isEqualToString:@"AbortJob"]) {
        ReportViewController *vc = [segue destinationViewController];
        [vc setSender:self];
        [vc setStatus:JOB_STATUS_ABORTED];
    }
}

#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (indexPath.section == 5) {
        if (self.status == JOB_STATUS_ACCEPTED) {
            // Complete button pressed
            [self performSegueWithIdentifier: @"CompleteJob" sender: self];

        } else if (self.status == JOB_STATUS_WAITING) {
            // Accept button pressed
            NSString *urlString = [[NSUserDefaults standardUserDefaults] stringForKey:@"database_url"];
            ASIFormDataRequest *request = [ASIFormDataRequest requestWithURL:[NSURL URLWithString:urlString]];
            [request setPostValue:@"update_job" forKey:@"request"];
            [request setPostValue:[NSString stringWithFormat:@"%d", self.jobId] forKey:@"job_id"];
            [request setPostValue:@"" forKey:@"closing_report"];
            [request setPostValue:[NSString stringWithFormat:@"%d", JOB_STATUS_ACCEPTED] forKey:@"status"];
            [request setDelegate:self];
            [request startAsynchronous];
            
            MBProgressHUD *hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
            hud.labelText = @"Accepting job...";
        }
    } else if (indexPath.section == 6) {
        // Abort button pressed
    }

    // Navigation logic may go here. Create and push another view controller.
    /*
     <#DetailViewController#> *detailViewController = [[<#DetailViewController#> alloc] initWithNibName:@"<#Nib name#>" bundle:nil];
     // ...
     // Pass the selected object to the new view controller.
     [self.navigationController pushViewController:detailViewController animated:YES];
     */
}

@end
