//
//  LoginViewController.m
//  PLS Mobile
//
//  Created by Daniel Workman on 16/04/2013.
//  Copyright (c) 2013 Daniel Workman. All rights reserved.
//

#import "LoginViewController.h"
#import "JFBCrypt.h"
#import "ASIHTTPRequest.h"
#import "ASIFormDataRequest.h"
#import "SBJson.h"
#import "MBProgressHUD.h"
#import "GlobalObjects.h"

@interface LoginViewController ()

@end

@implementation LoginViewController

@synthesize loginButton;
@synthesize username;
@synthesize password;
@synthesize rememberMe;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
    }
    return self;
}

- (IBAction)login:(id)sender {

    // Lose the keyboard
    [username resignFirstResponder];
    [password resignFirstResponder];

    // Start request
    NSString *urlString = [[NSUserDefaults standardUserDefaults] stringForKey:@"database_url"];
    ASIFormDataRequest *request = [ASIFormDataRequest requestWithURL:[NSURL URLWithString:urlString]];
    [request setPostValue:@"login" forKey:@"request"];
    [request setPostValue:username.text forKey:@"username"];
    [request setDelegate:self];
    [request startAsynchronous];

    MBProgressHUD *hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
    hud.labelText = @"Logging in...";
}

- (void)requestFinished:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];

    if (request.responseStatusCode == 400) {
        ALERT(@"Login failed", @"Invalid username or password");
    } else if (request.responseStatusCode == 200) {
        NSString *responseString = [request responseString];
        NSDictionary *responseDict = [responseString JSONValue];
        NSString *hash = [responseDict objectForKey:@"pw_hash"];
        NSString *salt = [responseDict objectForKey:@"pw_salt"];

        //NSString *salt = [JFBCrypt generateSaltWithNumberOfRounds: 10];
        NSString *newhash = [JFBCrypt hashPassword: password.text withSalt: salt];

        if ([newhash isEqualToString:hash]) {            
            // If "Remember Me" is set then store the data for next time or remove it if not
            NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];

            if(rememberMe.isOn)
            {
                [userDefaults setObject:username.text forKey:@"username"];
                [userDefaults setObject:password.text forKey:@"password"];
            }
            else
            {
                [userDefaults setObject:@"" forKey:@"username"];
                [userDefaults setObject:@"" forKey:@"password"];
            }
            
            [userDefaults synchronize];
            
            [GlobalObjects setCurrentUser:username.text];
            
            username.text = @"";
            password.text = @"";
            [self toggleLoginButton:NO];

            [self performSegueWithIdentifier:@"LogIn" sender:self];
        } else {
            ALERT(@"Login failed", @"Invalid username or password");
        }
    } else {
        ALERT(@"Request Failed", request.responseStatusMessage);
    }
}

- (void)requestFailed:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];
    NSError *error = [request error];
    ALERT(@"Request Failed", error.localizedDescription);
}

- (void)toggleLoginButton:(BOOL)enable {
    self.navigationItem.rightBarButtonItem = enable ? self.loginButton : nil;
}

- (IBAction)usernameChanged:(id)sender {
    [self toggleLoginButton:username.text.length > 0 && password.text.length > 0];
}

- (IBAction)passwordChanged:(id)sender {
    [self toggleLoginButton:username.text.length > 0 && password.text.length > 0];
}

- (void)viewDidLoad
{
	// Do any additional setup after loading the view.
    [super viewDidLoad];
    self.firstTime = TRUE;
    
    // Hardcoded login for dev purposes only!
    //[GlobalObjects setCurrentUser:@"workmandan"];
    //[self performSegueWithIdentifier:@"LogIn" sender:self];

    // Turn off the login button
    self.navigationItem.rightBarButtonItem = nil;
}

- (void)viewDidAppear:(BOOL)animated
{
    // Is "Remember Me" set?
    NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
    NSString *user = [userDefaults objectForKey:@"username"];
    NSString *pass = [userDefaults objectForKey:@"password"];
    
    if (pass && user && ![pass isEqualToString:@""] && ![user isEqualToString:@""])
    {
        username.text = user;
        password.text = pass;
        rememberMe.on = YES;
        [self toggleLoginButton:YES];
        
        if (self.firstTime) {
            self.firstTime = FALSE;
            [self login:nil];
        }
    }
    else
    {
        username.text = @"";
        password.text = @"";
        rememberMe.on = NO;
        [self toggleLoginButton:NO];
    }
    
    self.firstTime = FALSE;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    if ([[segue identifier] isEqualToString:@"LogIn"]) {
        return;
    }
}


@end
